==> 1.0.0.tar.gz: lib/src/core/Operator.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import '../sub_types/Operators.dart';

/*
<operator> ::= '~'
| <binaryOperator>
| '[]'
| '[]='

See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
Page 29
*/
class Operator extends ParserType {
  int caseNum;

  Operator(Lexer lexer) {
    int attempt, maxAttempts = 4;
    int snapShot = lexer.currentIndex;
    for (attempt = 0; attempt < maxAttempts; ++attempt) {
      try {
        switch (attempt) {
          case 0: _case0(lexer); break;
          case 1: _case1(lexer); break;
          case 2: _case2(lexer); break;
          case 3: _case3(lexer); break;
        }

        break;
      }
      on WrongTokenType {
        lexer.setPos(snapShot);
      }
    }

    if (attempt == maxAttempts)
      throw WrongTokenType('Tried all options in Operator: ALL FAILED');

  }
  
  /* '~' */
  void _case0(Lexer lexer) {
    checkType(lexer, TType.TILDE);
    lexer.advance();

    caseNum = 0;
  }
  
  /* <binaryOperator> */
  void _case1(Lexer lexer) {
    caseNum = 1;
  }
  
  /* '[]' */
  void _case2(Lexer lexer) {
    checkType(lexer, TType.LEFT_BRACKET);
    lexer.advance();
    checkType(lexer, TType.RIGHT_BRACKET);
    lexer.advance();

    caseNum = 2;
  }
  
  /* '[]=' */
  void _case3(Lexer lexer) {
    checkType(lexer, TType.LEFT_BRACKET);
    lexer.advance();
    checkType(lexer, TType.RIGHT_BRACKET);
    lexer.advance();
    checkType(lexer, TType.EQUALS);
    lexer.advance();

    caseNum = 3;
  }

  String toString() {
    switch (caseNum) {
      case 0: return '~'; break;
      case 1: return ''; break;
      case 2: return '[]'; break;
      case 3: return '[]='; break;
    }
    return '';
  }

}

/*
<binaryOperator> ::= <multiplicativeOperator>
| <additiveOperator>
| <shiftOperator>
| <relationalOperator>
| '=='
| <bitwiseOperator>
*/
class BinaryOperator extends ParserType {
  int caseNum;
  MultiplicativeOperator multiplicativeOperator;
  AdditiveOperator additiveOperator;
  ShiftOperator shiftOperator;
  RelationalOperator relationalOperator;
  BitwiseOperator bitwiseOperator;

  BinaryOperator(Lexer lexer) {
    int attempt, maxAttempts = 6;
    int snapShot = lexer.currentIndex;
    for (attempt = 0; attempt < maxAttempts; ++attempt) {
      try {
        switch (attempt) {
          case 0: _case0(lexer); break;
          case 1: _case1(lexer); break;
          case 2: _case2(lexer); break;
          case 3: _case3(lexer); break;
          case 4: _case4(lexer); break;
          case 5: _case5(lexer); break;
        }

        break;
      }
      on WrongTokenType {
        lexer.setPos(snapShot);
      }
    }

    if (attempt == maxAttempts)
      throw WrongTokenType('Tried all options in BinaryOperator: ALL FAILED');

  }
  
  /* <multiplicativeOperator> */
  void _case0(Lexer lexer) {
    multiplicativeOperator = MultiplicativeOperator(lexer);
    caseNum = 0;
  }
  
  /* <additiveOperator> */
  void _case1(Lexer lexer) {
    additiveOperator = AdditiveOperator(lexer);
    caseNum = 1;
  }
  
  /* <shiftOperator> */
  void _case2(Lexer lexer) {
    shiftOperator = ShiftOperator(lexer);
    caseNum = 2;
  }
  
  /* <relationalOperator> */
  void _case3(Lexer lexer) {
    relationalOperator = RelationalOperator(lexer);
    caseNum = 3;
  }
  
  /* '==' */
  void _case4(Lexer lexer) {
    checkType(lexer, TType.EQUALS);
    lexer.advance();
    checkType(lexer, TType.EQUALS);
    lexer.advance();

    caseNum = 4;
  }
  
  /* <bitwiseOperator> */
  void _case5(Lexer lexer) {
    bitwiseOperator = BitwiseOperator(lexer);
    caseNum = 5;
  }

  String toString() {
    switch (caseNum) {
      case 0: return '$multiplicativeOperator'; break;
      case 1: return '$additiveOperator'; break;
      case 2: return '$shiftOperator'; break;
      case 3: return '$relationalOperator'; break;
      case 4: return '=='; break;
      case 5: return '$bitwiseOperator'; break;
    }
    return '';
  }

}

==> 1.1.1.tar.gz: lib/src/core/Operator.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import '../sub_types/Operators.dart';

/// <operator> ::= '~'
/// | <binaryOperator>
/// | '[]'
/// | '[]='
///
/// See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
/// Page 29
class Operator extends ParserType {
  int caseNum;

  Operator(Lexer lexer) {
    int attempt, maxAttempts = 4;
    int snapShot = lexer.currentIndex;
    for (attempt = 0; attempt < maxAttempts; ++attempt) {
      try {
        switch (attempt) {
          case 0:
            _case0(lexer);
            break;
          case 1:
            _case1(lexer);
            break;
          case 2:
            _case2(lexer);
            break;
          case 3:
            _case3(lexer);
            break;
        }

        break;
      } on WrongTokenType {
        lexer.setPos(snapShot);
      }
    }

    if (attempt == maxAttempts) {
      throw WrongTokenType('Tried all options in Operator: ALL FAILED');
    }
  }

  /// '~'
  void _case0(Lexer lexer) {
    checkType(lexer, TType.TILDE);
    lexer.advance();

    caseNum = 0;
  }

  /// <binaryOperator>
  void _case1(Lexer lexer) {
    caseNum = 1;
  }

  /// '[]'
  void _case2(Lexer lexer) {
    checkType(lexer, TType.LEFT_BRACKET);
    lexer.advance();
    checkType(lexer, TType.RIGHT_BRACKET);
    lexer.advance();

    caseNum = 2;
  }

  /// '[]='
  void _case3(Lexer lexer) {
    checkType(lexer, TType.LEFT_BRACKET);
    lexer.advance();
    checkType(lexer, TType.RIGHT_BRACKET);
    lexer.advance();
    checkType(lexer, TType.EQUALS);
    lexer.advance();

    caseNum = 3;
  }

  String toString() {
    switch (caseNum) {
      case 0:
        return '~';
        break;
      case 1:
        return '';
        break;
      case 2:
        return '[]';
        break;
      case 3:
        return '[]=';
        break;
    }
    return '';
  }
}

/// <binaryOperator> ::= <multiplicativeOperator>
/// | <additiveOperator>
/// | <shiftOperator>
/// | <relationalOperator>
/// | '=='
/// | <bitwiseOperator>
class BinaryOperator extends ParserType {
  int caseNum;
  MultiplicativeOperator multiplicativeOperator;
  AdditiveOperator additiveOperator;
  ShiftOperator shiftOperator;
  RelationalOperator relationalOperator;
  BitwiseOperator bitwiseOperator;

  BinaryOperator(Lexer lexer) {
    int attempt, maxAttempts = 6;
    int snapShot = lexer.currentIndex;
    for (attempt = 0; attempt < maxAttempts; ++attempt) {
      try {
        switch (attempt) {
          case 0:
            _case0(lexer);
            break;
          case 1:
            _case1(lexer);
            break;
          case 2:
            _case2(lexer);
            break;
          case 3:
            _case3(lexer);
            break;
          case 4:
            _case4(lexer);
            break;
          case 5:
            _case5(lexer);
            break;
        }

        break;
      } on WrongTokenType {
        lexer.setPos(snapShot);
      }
    }

    if (attempt == maxAttempts) {
      throw WrongTokenType('Tried all options in BinaryOperator: ALL FAILED');
    }
  }

  /// <multiplicativeOperator>
  void _case0(Lexer lexer) {
    multiplicativeOperator = MultiplicativeOperator(lexer);
    caseNum = 0;
  }

  /// <additiveOperator>
  void _case1(Lexer lexer) {
    additiveOperator = AdditiveOperator(lexer);
    caseNum = 1;
  }

  /// <shiftOperator>
  void _case2(Lexer lexer) {
    shiftOperator = ShiftOperator(lexer);
    caseNum = 2;
  }

  /// <relationalOperator>
  void _case3(Lexer lexer) {
    relationalOperator = RelationalOperator(lexer);
    caseNum = 3;
  }

  /// '=='
  void _case4(Lexer lexer) {
    checkType(lexer, TType.EQUALS);
    lexer.advance();
    checkType(lexer, TType.EQUALS);
    lexer.advance();

    caseNum = 4;
  }

  /// <bitwiseOperator>
  void _case5(Lexer lexer) {
    bitwiseOperator = BitwiseOperator(lexer);
    caseNum = 5;
  }

  String toString() {
    switch (caseNum) {
      case 0:
        return '$multiplicativeOperator';
        break;
      case 1:
        return '$additiveOperator';
        break;
      case 2:
        return '$shiftOperator';
        break;
      case 3:
        return '$relationalOperator';
        break;
      case 4:
        return '==';
        break;
      case 5:
        return '$bitwiseOperator';
        break;
    }
    return '';
  }
}
